mystic.math module documentation
================================

approx module
-------------

.. automodule:: mystic.math.approx
    :members:
    :undoc-members:
    :show-inheritance:

compressed module
-----------------

.. automodule:: mystic.math.compressed
    :members:
    :undoc-members:
    :show-inheritance:

discrete module
---------------

.. automodule:: mystic.math.discrete
    :members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: point_mass, measure, product_measure, scenario
.. autoclass:: point_mass
    :members:
    :undoc-members:
    :show-inheritance:
.. autoclass:: measure
    :members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: coords, get_expect, mean
.. autoclass:: product_measure
    :members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: coords, get_expect
.. autoclass:: scenario
    :members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: coords, get_mean_value

distance module
---------------

.. automodule:: mystic.math.distance
    :members:
    :undoc-members:
    :show-inheritance:

grid module
-----------

.. automodule:: mystic.math.grid
    :members:
    :undoc-members:
    :show-inheritance:

integrate module
----------------

.. automodule:: mystic.math.integrate
    :members:
    :undoc-members:
    :show-inheritance:

interpolate module
------------------

.. automodule:: mystic.math.interpolate
    :members:
    :undoc-members:
    :show-inheritance:

legacydata module
-----------------

.. automodule:: mystic.math.legacydata
    :members:
    :undoc-members:
    :show-inheritance:

measures module
---------------

.. automodule:: mystic.math.measures
    :members:
    :undoc-members:
    :show-inheritance:
..  :exclude-members: _flat_split

poly module
-----------

.. automodule:: mystic.math.poly
    :members:
    :undoc-members:
    :show-inheritance:

samples module
--------------

.. automodule:: mystic.math.samples
    :members:
    :undoc-members:
    :show-inheritance:

stats module
------------

.. automodule:: mystic.math.stats
    :members:
    :undoc-members:
    :show-inheritance:

